==> knative-client-4.13.1-sources.jar: io/fabric8/knative/client/eventing/v1alpha1/internal/GitHubBindingOperationsImpl.java <==


                        
      
package io.fabric8.knative.client.eventing.v1alpha1.internal;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.knative.eventing.contrib.github.v1alpha1.DoneableGitHubBinding;
import io.fabric8.knative.eventing.contrib.github.v1alpha1.GitHubBinding;
import io.fabric8.knative.eventing.contrib.github.v1alpha1.GitHubBindingList;
import io.fabric8.knative.eventing.contrib.github.v1alpha1.DoneableGitHubBinding;

import java.util.Map;
import java.util.TreeMap;


public class GitHubBindingOperationsImpl extends HasMetadataOperation<GitHubBinding, GitHubBindingList, DoneableGitHubBinding, Resource<GitHubBinding, DoneableGitHubBinding>> {

  public GitHubBindingOperationsImpl(OkHttpClient client, Config config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public GitHubBindingOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("bindings.knative.dev")
    .withApiGroupVersion("v1alpha1")
    .withPlural("githubbindings"));
    this.type = GitHubBinding.class;
    this.listType = GitHubBindingList.class;
    this.doneableType = DoneableGitHubBinding.class;
  }

  public GitHubBindingOperationsImpl newInstance(OperationContext context) {
    return new GitHubBindingOperationsImpl(context);
  }

  @Override
  public boolean isResourceNamespaced() {
    return true;
  }
}

==> knative-client-5.4.1-sources.jar: io/fabric8/knative/client/eventing/v1alpha1/internal/GitHubBindingOperationsImpl.java <==


                        
      
package io.fabric8.knative.client.eventing.v1alpha1.internal;

import io.fabric8.kubernetes.api.builder.Visitor;
import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.knative.eventing.contrib.github.v1alpha1.GitHubBinding;
import io.fabric8.knative.eventing.contrib.github.v1alpha1.GitHubBindingBuilder;
import io.fabric8.knative.eventing.contrib.github.v1alpha1.GitHubBindingList;

import java.util.Map;
import java.util.TreeMap;


public class GitHubBindingOperationsImpl extends HasMetadataOperation<GitHubBinding, GitHubBindingList, Resource<GitHubBinding>> {

  public GitHubBindingOperationsImpl(OkHttpClient client, Config config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public GitHubBindingOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("bindings.knative.dev")
    .withApiGroupVersion("v1alpha1")
    .withPlural("githubbindings"));
    this.type = GitHubBinding.class;
    this.listType = GitHubBindingList.class;
  }

  public GitHubBindingOperationsImpl newInstance(OperationContext context) {
    return new GitHubBindingOperationsImpl(context);
  }

  @Override
  public GitHubBinding edit(Visitor... visitors) {
    return patch(new GitHubBindingBuilder(getMandatory()).accept(visitors).build());
  }
 
  @Override
  public boolean isResourceNamespaced() {
    return true;
  }
}
